diff --git a/accounts/abi/bind/backend.go b/accounts/abi/bind/backend.go
index 38ea44f056..5144bbba32 100644
--- a/accounts/abi/bind/backend.go
+++ b/accounts/abi/bind/backend.go
@@ -49,7 +49,7 @@ type ContractCaller interface {
CodeAt(ctx context.Context, contract common.Address, blockNumber *big.Int) ([]byte, error)
// ContractCall executes an EtherFact contract call with the specified data as the
// input.
- CallContract(ctx context.Context, call etherfact.CallMsg, blockNumber *big.Int) ([]byte, error)
+ CallContract(ctx context.Context, call ethereum.CallMsg, blockNumber *big.Int) ([]byte, error)
}
// PendingContractCaller defines methods to perform contract calls on the pending state.
@@ -59,7 +59,7 @@ type PendingContractCaller interface {
// PendingCodeAt returns the code of the given account in the pending state.
PendingCodeAt(ctx context.Context, contract common.Address) ([]byte, error)
// PendingCallContract executes an EtherFact contract call against the pending state.
- PendingCallContract(ctx context.Context, call etherfact.CallMsg) ([]byte, error)
+ PendingCallContract(ctx context.Context, call ethereum.CallMsg) ([]byte, error)
}
// ContractTransactor defines the methods needed to allow operating with contract
@@ -79,7 +79,7 @@ type ContractTransactor interface {
// There is no guarantee that this is the true gas limit requirement as other
// transactions may be added or removed by miners, but it should provide a basis
// for setting a reasonable default.
- EstimateGas(ctx context.Context, call etherfact.CallMsg) (gas uint64, err error)
+ EstimateGas(ctx context.Context, call ethereum.CallMsg) (gas uint64, err error)
// SendTransaction injects the transaction into the pending pool for execution.
SendTransaction(ctx context.Context, tx *types.Transaction) error
}
@@ -91,11 +91,11 @@ type ContractFilterer interface {
// returning all the results in one batch.
//
// TODO(karalabe): Deprecate when the subscription one can return past data too.
- FilterLogs(ctx context.Context, query etherfact.FilterQuery) ([]types.Log, error)
+ FilterLogs(ctx context.Context, query ethereum.FilterQuery) ([]types.Log, error)
// SubscribeFilterLogs creates a background log filtering operation, returning
// a subscription immediately, which can be used to stream the found events.
- SubscribeFilterLogs(ctx context.Context, query etherfact.FilterQuery, ch chan<- types.Log) (etherfact.Subscription, error)
+ SubscribeFilterLogs(ctx context.Context, query ethereum.FilterQuery, ch chan<- types.Log) (ethereum.Subscription, error)
}
// DeployBackend wraps the operations needed by WaitMined and WaitDeployed.
diff --git a/accounts/abi/bind/template.go b/accounts/abi/bind/template.go
index a310c8c63c..d2fde23862 100644
--- a/accounts/abi/bind/template.go
+++ b/accounts/abi/bind/template.go
@@ -427,8 +427,8 @@ const tmplSourceJava = `
package {{.Package}};
-import org.ethereum.geth.*;
-import org.ethereum.geth.internal.*;
+import org.ethereum.getf.*;
+import org.ethereum.getf.internal.*;
{{range $contract := .Contracts}}
public class {{.Type}} {
diff --git a/accounts/keystore/keystore_plain_test.go b/accounts/keystore/keystore_plain_test.go
index f233b4151c..48d8592f57 100644
--- a/accounts/keystore/keystore_plain_test.go
+++ b/accounts/keystore/keystore_plain_test.go
@@ -32,7 +32,7 @@ import (
)
func tmpKeyStoreIface(t *testing.T, encrypted bool) (dir string, ks keyStore) {
- d, err := ioutil.TempDir("", "geth-keystore-test")
+ d, err := ioutil.TempDir("", "getf-keystore-test")
if err != nil {
t.Fatal(err)
}
diff --git a/cmd/faucet/faucet.go b/cmd/faucet/faucet.go
index 03decc2068..e7c6ff2f66 100644
--- a/cmd/faucet/faucet.go
+++ b/cmd/faucet/faucet.go
@@ -215,7 +215,7 @@ type faucet struct {
func newFaucet(genesis *core.Genesis, port int, enodes []*discv5.Node, network uint64, stats string, ks *keystore.KeyStore, index []byte) (*faucet, error) {
// Assemble the raw devp2p protocol stack
stack, err := node.New(&node.Config{
- Name: "geth",
+ Name: "getf",
Version: params.Version,
DataDir: filepath.Join(os.Getenv("HOME"), ".faucet"),
P2P: p2p.Config{
diff --git a/cmd/geth/accountcmd.go b/cmd/getf/accountcmd.go
similarity index 97%
rename from cmd/geth/accountcmd.go
rename to cmd/getf/accountcmd.go
index 74dc120a41..48a3c9d6c7 100644
--- a/cmd/geth/accountcmd.go
+++ b/cmd/getf/accountcmd.go
@@ -36,7 +36,7 @@ var (
ArgsUsage: "",
Category: "ACCOUNT COMMANDS",
Description: `
- geth wallet import /path/to/my/presale.wallet
+ getf wallet import /path/to/my/presale.wallet
will prompt for your password and imports your ether presale account.
It can be used non-interactively with the --password option taking a
@@ -56,7 +56,7 @@ passwordfile as argument containing the wallet password in plaintext.`,
utils.LightKDFFlag,
},
Description: `
- geth wallet [options] /path/to/my/presale.wallet
+ getf wallet [options] /path/to/my/presale.wallet
will prompt for your password and imports your ether presale account.
It can be used non-interactively with the --password option taking a
@@ -112,7 +112,7 @@ Print a short summary of all accounts`,
utils.LightKDFFlag,
},
Description: `
- geth account new
+ getf account new
Creates a new account and prints the address.
@@ -137,7 +137,7 @@ password to file or expose in any other way.
utils.LightKDFFlag,
},
Description: `
- geth account update
+ getf account update
Update an existing account.
@@ -149,7 +149,7 @@ format to the newest format or change the password for an account.
For non-interactive use the passphrase can be specified with the --password flag:
- geth account update [options]
+ getf account update [options]
Since only one password can be given, only format update can be performed,
changing your password is only possible interactively.
@@ -167,7 +167,7 @@ changing your password is only possible interactively.
},
ArgsUsage: "",
Description: `
- geth account import
+ getf account import
Imports an unencrypted private key from and creates a new account.
Prints the address.
@@ -180,7 +180,7 @@ You must remember this passphrase to unlock your account in the future.
For non-interactive use the passphrase can be specified with the -password flag:
- geth account import [options]
+ getf account import [options]
Note:
As you can directly copy your encrypted accounts to another ethereum instance,
diff --git a/cmd/geth/accountcmd_test.go b/cmd/getf/accountcmd_test.go
similarity index 85%
rename from cmd/geth/accountcmd_test.go
rename to cmd/getf/accountcmd_test.go
index 2232ef13fb..c3ada40725 100644
--- a/cmd/geth/accountcmd_test.go
+++ b/cmd/getf/accountcmd_test.go
@@ -43,22 +43,22 @@ func tmpDatadirWithKeystore(t *testing.T) string {
}
func TestAccountListEmpty(t *testing.T) {
- geth := runGeth(t, "account", "list")
- geth.ExpectExit()
+ getf := runGeth(t, "account", "list")
+ getf.ExpectExit()
}
func TestAccountList(t *testing.T) {
datadir := tmpDatadirWithKeystore(t)
- geth := runGeth(t, "account", "list", "--datadir", datadir)
- defer geth.ExpectExit()
+ getf := runGeth(t, "account", "list", "--datadir", datadir)
+ defer getf.ExpectExit()
if runtime.GOOS == "windows" {
- geth.Expect(`
+ getf.Expect(`
Account #0: {7ef5a6135f1fd6a02593eedc869c6d41d934aef8} keystore://{{.Datadir}}\keystore\UTC--2016-03-22T12-57-55.920751759Z--7ef5a6135f1fd6a02593eedc869c6d41d934aef8
Account #1: {f466859ead1932d743d622cb74fc058882e8648a} keystore://{{.Datadir}}\keystore\aaa
Account #2: {289d485d9771714cce91d3393d764e1311907acc} keystore://{{.Datadir}}\keystore\zzz
`)
} else {
- geth.Expect(`
+ getf.Expect(`
Account #0: {7ef5a6135f1fd6a02593eedc869c6d41d934aef8} keystore://{{.Datadir}}/keystore/UTC--2016-03-22T12-57-55.920751759Z--7ef5a6135f1fd6a02593eedc869c6d41d934aef8
Account #1: {f466859ead1932d743d622cb74fc058882e8648a} keystore://{{.Datadir}}/keystore/aaa
Account #2: {289d485d9771714cce91d3393d764e1311907acc} keystore://{{.Datadir}}/keystore/zzz
@@ -67,21 +67,21 @@ Account #2: {289d485d9771714cce91d3393d764e1311907acc} keystore://{{.Datadir}}/k
}
func TestAccountNew(t *testing.T) {
- geth := runGeth(t, "account", "new", "--lightkdf")
- defer geth.ExpectExit()
- geth.Expect(`
+ getf := runGeth(t, "account", "new", "--lightkdf")
+ defer getf.ExpectExit()
+ getf.Expect(`
Your new account is locked with a password. Please give a password. Do not forget this password.
!! Unsupported terminal, password will be echoed.
Passphrase: {{.InputLine "foobar"}}
Repeat passphrase: {{.InputLine "foobar"}}
`)
- geth.ExpectRegexp(`Address: \{[0-9a-f]{40}\}\n`)
+ getf.ExpectRegexp(`Address: \{[0-9a-f]{40}\}\n`)
}
func TestAccountNewBadRepeat(t *testing.T) {
- geth := runGeth(t, "account", "new", "--lightkdf")
- defer geth.ExpectExit()
- geth.Expect(`
+ getf := runGeth(t, "account", "new", "--lightkdf")
+ defer getf.ExpectExit()
+ getf.Expect(`
Your new account is locked with a password. Please give a password. Do not forget this password.
!! Unsupported terminal, password will be echoed.
Passphrase: {{.InputLine "something"}}
@@ -92,11 +92,11 @@ Fatal: Passphrases do not match
func TestAccountUpdate(t *testing.T) {
datadir := tmpDatadirWithKeystore(t)
- geth := runGeth(t, "account", "update",
+ getf := runGeth(t, "account", "update",
"--datadir", datadir, "--lightkdf",
"f466859ead1932d743d622cb74fc058882e8648a")
- defer geth.ExpectExit()
- geth.Expect(`
+ defer getf.ExpectExit()
+ getf.Expect(`
Unlocking account f466859ead1932d743d622cb74fc058882e8648a | Attempt 1/3
!! Unsupported terminal, password will be echoed.
Passphrase: {{.InputLine "foobar"}}
@@ -107,24 +107,24 @@ Repeat passphrase: {{.InputLine "foobar2"}}
}
func TestWalletImport(t *testing.T) {
- geth := runGeth(t, "wallet", "import", "--lightkdf", "testdata/guswallet.json")
- defer geth.ExpectExit()
- geth.Expect(`
+ getf := runGeth(t, "wallet", "import", "--lightkdf", "testdata/guswallet.json")
+ defer getf.ExpectExit()
+ getf.Expect(`
!! Unsupported terminal, password will be echoed.
Passphrase: {{.InputLine "foo"}}
Address: {d4584b5f6229b7be90727b0fc8c6b91bb427821f}
`)
- files, err := ioutil.ReadDir(filepath.Join(geth.Datadir, "keystore"))
+ files, err := ioutil.ReadDir(filepath.Join(getf.Datadir, "keystore"))
if len(files) != 1 {
t.Errorf("expected one key file in keystore directory, found %d files (error: %v)", len(files), err)
}
}
func TestWalletImportBadPassword(t *testing.T) {
- geth := runGeth(t, "wallet", "import", "--lightkdf", "testdata/guswallet.json")
- defer geth.ExpectExit()
- geth.Expect(`
+ getf := runGeth(t, "wallet", "import", "--lightkdf", "testdata/guswallet.json")
+ defer getf.ExpectExit()
+ getf.Expect(`
!! Unsupported terminal, password will be echoed.
Passphrase: {{.InputLine "wrong"}}
Fatal: could not decrypt key with given passphrase
@@ -133,23 +133,23 @@ Fatal: could not decrypt key with given passphrase
func TestUnlockFlag(t *testing.T) {
datadir := tmpDatadirWithKeystore(t)
- geth := runGeth(t,
+ getf := runGeth(t,
"--datadir", datadir, "--nat", "none", "--nodiscover", "--maxpeers", "0", "--port", "0",
"--unlock", "f466859ead1932d743d622cb74fc058882e8648a",
"js", "testdata/empty.js")
- geth.Expect(`
+ getf.Expect(`
Unlocking account f466859ead1932d743d622cb74fc058882e8648a | Attempt 1/3
!! Unsupported terminal, password will be echoed.
Passphrase: {{.InputLine "foobar"}}
`)
- geth.ExpectExit()
+ getf.ExpectExit()
wantMessages := []string{
"Unlocked account",
"=0xf466859eAD1932D743d622CB74FC058882E8648A",
}
for _, m := range wantMessages {
- if !strings.Contains(geth.StderrText(), m) {
+ if !strings.Contains(getf.StderrText(), m) {
t.Errorf("stderr text does not contain %q", m)
}
}
@@ -157,11 +157,11 @@ Passphrase: {{.InputLine "foobar"}}
func TestUnlockFlagWrongPassword(t *testing.T) {
datadir := tmpDatadirWithKeystore(t)
- geth := runGeth(t,
+ getf := runGeth(t,
"--datadir", datadir, "--nat", "none", "--nodiscover", "--maxpeers", "0", "--port", "0",
"--unlock", "f466859ead1932d743d622cb74fc058882e8648a")
- defer geth.ExpectExit()
- geth.Expect(`
+ defer getf.ExpectExit()
+ getf.Expect(`
Unlocking account f466859ead1932d743d622cb74fc058882e8648a | Attempt 1/3
!! Unsupported terminal, password will be echoed.
Passphrase: {{.InputLine "wrong1"}}
@@ -176,18 +176,18 @@ Fatal: Failed to unlock account f466859ead1932d743d622cb74fc058882e8648a (could
// https://github.com/EtherFact-Project/go-etherfact/issues/1785
func TestUnlockFlagMultiIndex(t *testing.T) {
datadir := tmpDatadirWithKeystore(t)
- geth := runGeth(t,
+ getf := runGeth(t,
"--datadir", datadir, "--nat", "none", "--nodiscover", "--maxpeers", "0", "--port", "0",
"--unlock", "0,2",
"js", "testdata/empty.js")
- geth.Expect(`
+ getf.Expect(`
Unlocking account 0 | Attempt 1/3
!! Unsupported terminal, password will be echoed.
Passphrase: {{.InputLine "foobar"}}
Unlocking account 2 | Attempt 1/3
Passphrase: {{.InputLine "foobar"}}
`)
- geth.ExpectExit()
+ getf.ExpectExit()
wantMessages := []string{
"Unlocked account",
@@ -195,7 +195,7 @@ Passphrase: {{.InputLine "foobar"}}
"=0x289d485D9771714CCe91D3393D764E1311907ACc",
}
for _, m := range wantMessages {
- if !strings.Contains(geth.StderrText(), m) {
+ if !strings.Contains(getf.StderrText(), m) {
t.Errorf("stderr text does not contain %q", m)
}
}
@@ -203,11 +203,11 @@ Passphrase: {{.InputLine "foobar"}}
func TestUnlockFlagPasswordFile(t *testing.T) {
datadir := tmpDatadirWithKeystore(t)
- geth := runGeth(t,
+ getf := runGeth(t,
"--datadir", datadir, "--nat", "none", "--nodiscover", "--maxpeers", "0", "--port", "0",
"--password", "testdata/passwords.txt", "--unlock", "0,2",
"js", "testdata/empty.js")
- geth.ExpectExit()
+ getf.ExpectExit()
wantMessages := []string{
"Unlocked account",
@@ -215,7 +215,7 @@ func TestUnlockFlagPasswordFile(t *testing.T) {
"=0x289d485D9771714CCe91D3393D764E1311907ACc",
}
for _, m := range wantMessages {
- if !strings.Contains(geth.StderrText(), m) {
+ if !strings.Contains(getf.StderrText(), m) {
t.Errorf("stderr text does not contain %q", m)
}
}
@@ -223,29 +223,29 @@ func TestUnlockFlagPasswordFile(t *testing.T) {
func TestUnlockFlagPasswordFileWrongPassword(t *testing.T) {
datadir := tmpDatadirWithKeystore(t)
- geth := runGeth(t,
+ getf := runGeth(t,
"--datadir", datadir, "--nat", "none", "--nodiscover", "--maxpeers", "0", "--port", "0",
"--password", "testdata/wrong-passwords.txt", "--unlock", "0,2")
- defer geth.ExpectExit()
- geth.Expect(`
+ defer getf.ExpectExit()
+ getf.Expect(`
Fatal: Failed to unlock account 0 (could not decrypt key with given passphrase)
`)
}
func TestUnlockFlagAmbiguous(t *testing.T) {
store := filepath.Join("..", "..", "accounts", "keystore", "testdata", "dupes")
- geth := runGeth(t,
+ getf := runGeth(t,
"--keystore", store, "--nat", "none", "--nodiscover", "--maxpeers", "0", "--port", "0",
"--unlock", "f466859ead1932d743d622cb74fc058882e8648a",
"js", "testdata/empty.js")
- defer geth.ExpectExit()
+ defer getf.ExpectExit()
// Helper for the expect template, returns absolute keystore path.
- geth.SetTemplateFunc("keypath", func(file string) string {
+ getf.SetTemplateFunc("keypath", func(file string) string {
abs, _ := filepath.Abs(filepath.Join(store, file))
return abs
})
- geth.Expect(`
+ getf.Expect(`
Unlocking account f466859ead1932d743d622cb74fc058882e8648a | Attempt 1/3
!! Unsupported terminal, password will be echoed.
Passphrase: {{.InputLine "foobar"}}
@@ -257,14 +257,14 @@ Your passphrase unlocked keystore://{{keypath "1"}}
In order to avoid this warning, you need to remove the following duplicate key files:
keystore://{{keypath "2"}}
`)
- geth.ExpectExit()
+ getf.ExpectExit()
wantMessages := []string{
"Unlocked account",
"=0xf466859eAD1932D743d622CB74FC058882E8648A",
}
for _, m := range wantMessages {
- if !strings.Contains(geth.StderrText(), m) {
+ if !strings.Contains(getf.StderrText(), m) {
t.Errorf("stderr text does not contain %q", m)
}
}
@@ -272,17 +272,17 @@ In order to avoid this warning, you need to remove the following duplicate key f
func TestUnlockFlagAmbiguousWrongPassword(t *testing.T) {
store := filepath.Join("..", "..", "accounts", "keystore", "testdata", "dupes")
- geth := runGeth(t,
+ getf := runGeth(t,
"--keystore", store, "--nat", "none", "--nodiscover", "--maxpeers", "0", "--port", "0",
"--unlock", "f466859ead1932d743d622cb74fc058882e8648a")
- defer geth.ExpectExit()
+ defer getf.ExpectExit()
// Helper for the expect template, returns absolute keystore path.
- geth.SetTemplateFunc("keypath", func(file string) string {
+ getf.SetTemplateFunc("keypath", func(file string) string {
abs, _ := filepath.Abs(filepath.Join(store, file))
return abs
})
- geth.Expect(`
+ getf.Expect(`
Unlocking account f466859ead1932d743d622cb74fc058882e8648a | Attempt 1/3
!! Unsupported terminal, password will be echoed.
Passphrase: {{.InputLine "wrong"}}
@@ -292,5 +292,5 @@ Multiple key files exist for address f466859ead1932d743d622cb74fc058882e8648a:
Testing your passphrase against all of them...
Fatal: None of the listed files could be unlocked.
`)
- geth.ExpectExit()
+ getf.ExpectExit()
}
diff --git a/cmd/geth/bugcmd.go b/cmd/getf/bugcmd.go
similarity index 98%
rename from cmd/geth/bugcmd.go
rename to cmd/getf/bugcmd.go
index 7c897a2577..2930e90792 100644
--- a/cmd/geth/bugcmd.go
+++ b/cmd/getf/bugcmd.go
@@ -36,7 +36,7 @@ import (
var bugCommand = cli.Command{
Action: utils.MigrateFlags(reportBug),
Name: "bug",
- Usage: "opens a window to report a bug on the geth repo",
+ Usage: "opens a window to report a bug on the getf repo",
ArgsUsage: " ",
Category: "MISCELLANEOUS COMMANDS",
}
diff --git a/cmd/geth/chaincmd.go b/cmd/getf/chaincmd.go
similarity index 100%
rename from cmd/geth/chaincmd.go
rename to cmd/getf/chaincmd.go
diff --git a/cmd/geth/config.go b/cmd/getf/config.go
similarity index 99%
rename from cmd/geth/config.go
rename to cmd/getf/config.go
index 08afe421f6..f8fbcb2731 100644
--- a/cmd/geth/config.go
+++ b/cmd/getf/config.go
@@ -103,7 +103,7 @@ func defaultNodeConfig() node.Config {
cfg.Version = params.VersionWithCommit(gitCommit)
cfg.HTTPModules = append(cfg.HTTPModules, "eth", "shh")
cfg.WSModules = append(cfg.WSModules, "eth", "shh")
- cfg.IPCPath = "geth.ipc"
+ cfg.IPCPath = "getf.ipc"
return cfg
}
diff --git a/cmd/geth/dao_test.go b/cmd/getf/dao_test.go
similarity index 97%
rename from cmd/geth/dao_test.go
rename to cmd/getf/dao_test.go
index 3cdebeb1e4..e0b66c5e75 100644
--- a/cmd/geth/dao_test.go
+++ b/cmd/getf/dao_test.go
@@ -116,11 +116,11 @@ func testDAOForkBlockNewChain(t *testing.T, test int, genesis string, expectBloc
} else {
// Force chain initialization
args := []string{"--port", "0", "--maxpeers", "0", "--nodiscover", "--nat", "none", "--ipcdisable", "--datadir", datadir}
- geth := runGeth(t, append(args, []string{"--exec", "2+2", "console"}...)...)
- geth.WaitExit()
+ getf := runGeth(t, append(args, []string{"--exec", "2+2", "console"}...)...)
+ getf.WaitExit()
}
// Retrieve the DAO config flag from the database
- path := filepath.Join(datadir, "geth", "chaindata")
+ path := filepath.Join(datadir, "getf", "chaindata")
db, err := ethdb.NewLDBDatabase(path, 0, 0)
if err != nil {
t.Fatalf("test %d: failed to open test database: %v", test, err)
diff --git a/cmd/geth/genesis_test.go b/cmd/getf/genesis_test.go
similarity index 97%
rename from cmd/geth/genesis_test.go
rename to cmd/getf/genesis_test.go
index 74547ef68f..c5a8e86b2b 100644
--- a/cmd/geth/genesis_test.go
+++ b/cmd/getf/genesis_test.go
@@ -100,11 +100,11 @@ func TestCustomGenesis(t *testing.T) {
runGeth(t, "--datadir", datadir, "init", json).WaitExit()
// Query the custom genesis block
- geth := runGeth(t,
+ getf := runGeth(t,
"--datadir", datadir, "--maxpeers", "0", "--port", "0",
"--nodiscover", "--nat", "none", "--ipcdisable",
"--exec", tt.query, "console")
- geth.ExpectRegexp(tt.result)
- geth.ExpectExit()
+ getf.ExpectRegexp(tt.result)
+ getf.ExpectExit()
}
}
diff --git a/cmd/geth/misccmd.go b/cmd/getf/misccmd.go
similarity index 95%
rename from cmd/geth/misccmd.go
rename to cmd/getf/misccmd.go
index 0899227f39..0cba60b7ce 100644
--- a/cmd/geth/misccmd.go
+++ b/cmd/getf/misccmd.go
@@ -80,7 +80,7 @@ The output of this command is supposed to be machine-readable.
func makecache(ctx *cli.Context) error {
args := ctx.Args()
if len(args) != 2 {
- utils.Fatalf(`Usage: geth makecache `)
+ utils.Fatalf(`Usage: getf makecache `)
}
block, err := strconv.ParseUint(args[0], 0, 64)
if err != nil {
@@ -95,7 +95,7 @@ func makecache(ctx *cli.Context) error {
func makedag(ctx *cli.Context) error {
args := ctx.Args()
if len(args) != 2 {
- utils.Fatalf(`Usage: geth makedag `)
+ utils.Fatalf(`Usage: getf makedag `)
}
block, err := strconv.ParseUint(args[0], 0, 64)
if err != nil {
@@ -134,6 +134,6 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
-along with geth. If not, see .`)
+along with getf. If not, see .`)
return nil
}
diff --git a/cmd/geth/testdata/empty.js b/cmd/getf/testdata/empty.js
similarity index 100%
rename from cmd/geth/testdata/empty.js
rename to cmd/getf/testdata/empty.js
diff --git a/cmd/geth/testdata/guswallet.json b/cmd/getf/testdata/guswallet.json
similarity index 100%
rename from cmd/geth/testdata/guswallet.json
rename to cmd/getf/testdata/guswallet.json
diff --git a/cmd/geth/testdata/passwords.txt b/cmd/getf/testdata/passwords.txt
similarity index 100%
rename from cmd/geth/testdata/passwords.txt
rename to cmd/getf/testdata/passwords.txt
diff --git a/cmd/geth/testdata/wrong-passwords.txt b/cmd/getf/testdata/wrong-passwords.txt
similarity index 100%
rename from cmd/geth/testdata/wrong-passwords.txt
rename to cmd/getf/testdata/wrong-passwords.txt
diff --git a/cmd/geth/usage.go b/cmd/getf/usage.go
similarity index 99%
rename from cmd/geth/usage.go
rename to cmd/getf/usage.go
index ebd9c86014..845662fce7 100644
--- a/cmd/geth/usage.go
+++ b/cmd/getf/usage.go
@@ -14,7 +14,7 @@
// You should have received a copy of the GNU General Public License
// along with go-etherfact. If not, see .
-// Contains the geth command usage template and generator.
+// Contains the getf command usage template and generator.
package main
diff --git a/cmd/puppeth/module_dashboard.go b/cmd/puppeth/module_dashboard.go
index 19acda1047..4f8eba29f9 100644
--- a/cmd/puppeth/module_dashboard.go
+++ b/cmd/puppeth/module_dashboard.go
@@ -84,7 +84,7 @@ var dashboardContent = `
{{if .FaucetPage}}{{end}}
diff --git a/build/ci.go b/build/ci.go
index 29172e1b87..f5d9f43b9f 100644
--- a/build/ci.go
+++ b/build/ci.go
@@ -62,19 +62,19 @@ import (
)
var (
// Files that end up in the geth*.zip archive.
gethArchiveFiles = []string{
"COPYING",
- executablePath("geth"),
+ executablePath("getf"),
}
// Files that end up in the geth-alltools*.zip archive.
allToolsArchiveFiles = []string{
"COPYING",
executablePath("abigen"),
executablePath("bootnode"),
executablePath("evm"),
- executablePath("geth"),
+ executablePath("getf"),
executablePath("puppeth"),
executablePath("rlpdump"),
executablePath("swarm"),
@@ -96,7 +96,7 @@ var (
Description: "Developer utility version of the EVM (Ethereum Virtual Machine) that is capable of running bytecode snippets within a configurable environment and execution mode.",
},
{
- Name: "geth",
+ Name: "getf",
Description: "Ethereum CLI client.",
},
{
@@ -368,17 +368,17 @@ func doArchive(cmdline []string) {
var (
env = build.Env()
base = archiveBasename(*arch, env)
- geth = "geth-" + base + ext
- alltools = "geth-alltools-" + base + ext
+ getf = "getf-" + base + ext
+ alltools = "getf-alltools-" + base + ext
)
maybeSkipArchive(env)
- if err := build.WriteArchive(geth, gethArchiveFiles); err != nil {
+ if err := build.WriteArchive(getf, gethArchiveFiles); err != nil {
log.Fatal(err)
}
if err := build.WriteArchive(alltools, allToolsArchiveFiles); err != nil {
log.Fatal(err)
}
- for _, archive := range []string{geth, alltools} {
+ for _, archive := range []string{getf, alltools} {
if err := archiveUpload(archive, *upload, *signer); err != nil {
log.Fatal(err)
}
@@ -505,7 +505,7 @@ func makeWorkdir(wdflag string) string {
if wdflag != "" {
err = os.MkdirAll(wdflag, 0744)
} else {
- wdflag, err = ioutil.TempDir("", "geth-build-")
+ wdflag, err = ioutil.TempDir("", "getf-build-")
}
if err != nil {
log.Fatal(err)
@@ -661,7 +661,7 @@ func doWindowsInstaller(cmdline []string) {
continue
}
allTools = append(allTools, filepath.Base(file))
- if filepath.Base(file) == "geth.exe" {
+ if filepath.Base(file) == "getf.exe" {
gethTool = file
} else {
devTools = append(devTools, file)
@@ -669,13 +669,13 @@ func doWindowsInstaller(cmdline []string) {
}
// Render NSIS scripts: Installer NSIS contains two installer sections,
// first section contains the geth binary, second section holds the dev tools.
templateData := map[string]interface{}{
"License": "COPYING",
"Geth": gethTool,
"DevTools": devTools,
}
- build.Render("build/nsis.geth.nsi", filepath.Join(*workdir, "geth.nsi"), 0644, nil)
+ build.Render("build/nsis.getf.nsi", filepath.Join(*workdir, "getf.nsi"), 0644, nil)
build.Render("build/nsis.install.nsh", filepath.Join(*workdir, "install.nsh"), 0644, templateData)
build.Render("build/nsis.uninstall.nsh", filepath.Join(*workdir, "uninstall.nsh"), 0644, allTools)
build.Render("build/nsis.pathupdate.nsh", filepath.Join(*workdir, "PathUpdate.nsh"), 0644, nil)
@@ -690,14 +690,14 @@ func doWindowsInstaller(cmdline []string) {
if env.Commit != "" {
version[2] += "-" + env.Commit[:8]
}
- installer, _ := filepath.Abs("geth-" + archiveBasename(*arch, env) + ".exe")
+ installer, _ := filepath.Abs("getf-" + archiveBasename(*arch, env) + ".exe")
build.MustRunCommand("makensis.exe",
"/DOUTPUTFILE="+installer,
"/DMAJORVERSION="+version[0],
"/DMINORVERSION="+version[1],
"/DBUILDVERSION="+version[2],
"/DARCH="+*arch,
- filepath.Join(*workdir, "geth.nsi"),
+ filepath.Join(*workdir, "getf.nsi"),
)
// Sign and publish installer.
@@ -732,7 +732,7 @@ func doAndroidArchive(cmdline []string) {
if *local {
// If we're building locally, copy bundle to build dir and skip Maven
- os.Rename("geth.aar", filepath.Join(GOBIN, "geth.aar"))
+ os.Rename("getf.aar", filepath.Join(GOBIN, "getf.aar"))
return
}
meta := newMavenMetadata(env)
@@ -742,8 +742,8 @@ func doAndroidArchive(cmdline []string) {
maybeSkipArchive(env)
// Sign and upload the archive to Azure
- archive := "geth-" + archiveBasename("android", env) + ".aar"
- os.Rename("geth.aar", archive)
+ archive := "getf-" + archiveBasename("android", env) + ".aar"
+ os.Rename("getf.aar", archive)
if err := archiveUpload(archive, *upload, *signer); err != nil {
log.Fatal(err)
@@ -828,7 +828,7 @@ func newMavenMetadata(env build.Environment) mavenMetadata {
}
return mavenMetadata{
Version: version,
- Package: "geth-" + version,
+ Package: "getf-" + version,
Develop: isUnstableBuild(env),
Contributors: contribs,
}
@@ -857,7 +857,7 @@ func doXCodeFramework(cmdline []string) {
build.MustRun(bind)
return
}
- archive := "geth-" + archiveBasename("ios", env)
+ archive := "getf-" + archiveBasename("ios", env)
if err := os.Mkdir(archive, os.ModePerm); err != nil {
log.Fatal(err)
}
@@ -62,19 +62,19 @@ import (
)
var (
- // Files that end up in the geth*.zip archive.
+ // Files that end up in the getf*.zip archive.
gethArchiveFiles = []string{
"COPYING",
@@ -62,19 +62,19 @@ import (
}
- // Files that end up in the geth-alltools*.zip archive.
+ // Files that end up in the getf-alltools*.zip archive.
allToolsArchiveFiles = []string{
"COPYING",
@@ -669,13 +669,13 @@ func doWindowsInstaller(cmdline []string) {
}
// Render NSIS scripts: Installer NSIS contains two installer sections,
- // first section contains the geth binary, second section holds the dev tools.
+ // first section contains the getf binary, second section holds the dev tools.
templateData := map[string]interface{}{
"License": "COPYING",
diff --git a/cmd/geth/consolecmd.go b/cmd/getf/consolecmd.go
similarity index 90%
rename from cmd/geth/consolecmd.go
rename to cmd/getf/consolecmd.go
index 068ca2a23f..8449fe42a8 100644
--- a/cmd/geth/consolecmd.go
+++ b/cmd/getf/consolecmd.go
@@ -57,7 +57,7 @@ See https://github.com/EtherFact-Project/go-etherfact/wiki/JavaScript-Console.`,
The Geth console is an interactive shell for the JavaScript runtime environment
which exposes a node admin interface as well as the Ðapp JavaScript API.
See https://github.com/EtherFact-Project/go-etherfact/wiki/JavaScript-Console.
-This command allows to open a console on a running geth node.`,
+This command allows to open a console on a running getf node.`,
}
javascriptCommand = cli.Command{
@@ -73,7 +73,7 @@ JavaScript API. See https://github.com/EtherFact-Project/go-etherfact/wiki/JavaS
}
)
// localConsole starts a new geth node, attaching a JavaScript console to it at the
// same time.
func localConsole(ctx *cli.Context) error {
// Create and start the node based on the CLI flags
@@ -84,7 +84,7 @@ func localConsole(ctx *cli.Context) error {
// Attach to the newly started node and start the JavaScript console
client, err := node.Attach()
if err != nil {
- utils.Fatalf("Failed to attach to the inproc geth: %v", err)
+ utils.Fatalf("Failed to attach to the inproc getf: %v", err)
}
config := console.Config{
DataDir: utils.MakeDataDir(ctx),
@@ -111,10 +111,10 @@ func localConsole(ctx *cli.Context) error {
return nil
}
// remoteConsole will connect to a remote geth instance, attaching a JavaScript
// console to it.
func remoteConsole(ctx *cli.Context) error {
// Attach to a remotely running geth instance and start the JavaScript console
endpoint := ctx.Args().First()
if endpoint == "" {
path := node.DefaultDataDir()
@@ -128,11 +128,11 @@ func remoteConsole(ctx *cli.Context) error {
path = filepath.Join(path, "rinkeby")
}
}
- endpoint = fmt.Sprintf("%s/geth.ipc", path)
+ endpoint = fmt.Sprintf("%s/getf.ipc", path)
}
client, err := dialRPC(endpoint)
if err != nil {
- utils.Fatalf("Unable to attach to remote geth: %v", err)
+ utils.Fatalf("Unable to attach to remote getf: %v", err)
}
config := console.Config{
DataDir: utils.MakeDataDir(ctx),
@@ -161,19 +161,19 @@ func remoteConsole(ctx *cli.Context) error {
// dialRPC returns a RPC client which connects to the given endpoint.
// The check for empty endpoint implements the defaulting logic
// for "geth attach" and "geth monitor" with no argument.
func dialRPC(endpoint string) (*rpc.Client, error) {
if endpoint == "" {
endpoint = node.DefaultIPCEndpoint(clientIdentifier)
} else if strings.HasPrefix(endpoint, "rpc:") || strings.HasPrefix(endpoint, "ipc:") {
// Backwards compatibility with geth < 1.5 which required
// these prefixes.
endpoint = endpoint[4:]
}
return rpc.Dial(endpoint)
}
// ephemeralConsole starts a new geth node, attaches an ephemeral JavaScript
// console to it, executes each of the files specified as arguments and tears
// everything down.
func ephemeralConsole(ctx *cli.Context) error {
@@ -185,7 +185,7 @@ func ephemeralConsole(ctx *cli.Context) error {
// Attach to the newly started node and start the JavaScript console
client, err := node.Attach()
if err != nil {
- utils.Fatalf("Failed to attach to the inproc geth: %v", err)
+ utils.Fatalf("Failed to attach to the inproc getf: %v", err)
}
config := console.Config{
DataDir: utils.MakeDataDir(ctx),
@@ -73,7 +73,7 @@ JavaScript API. See https://github.com/EtherFact-Project/go-etherfact/wiki/JavaS
}
)
-// localConsole starts a new geth node, attaching a JavaScript console to it at the
+// localConsole starts a new getf node, attaching a JavaScript console to it at the
// same time.
func localConsole(ctx *cli.Context) error {
@@ -111,10 +111,10 @@ func localConsole(ctx *cli.Context) error {
return nil
}
-// remoteConsole will connect to a remote geth instance, attaching a JavaScript
+// remoteConsole will connect to a remote getf instance, attaching a JavaScript
// console to it.
func remoteConsole(ctx *cli.Context) error {
@@ -111,10 +111,10 @@ func localConsole(ctx *cli.Context) error {
// console to it.
func remoteConsole(ctx *cli.Context) error {
- // Attach to a remotely running geth instance and start the JavaScript console
+ // Attach to a remotely running getf instance and start the JavaScript console
endpoint := ctx.Args().First()
if endpoint == "" {
@@ -161,19 +161,19 @@ func remoteConsole(ctx *cli.Context) error {
// dialRPC returns a RPC client which connects to the given endpoint.
// The check for empty endpoint implements the defaulting logic
-// for "geth attach" and "geth monitor" with no argument.
+// for "getf attach" and "getf monitor" with no argument.
func dialRPC(endpoint string) (*rpc.Client, error) {
if endpoint == "" {
@@ -161,19 +161,19 @@ func remoteConsole(ctx *cli.Context) error {
endpoint = node.DefaultIPCEndpoint(clientIdentifier)
} else if strings.HasPrefix(endpoint, "rpc:") || strings.HasPrefix(endpoint, "ipc:") {
- // Backwards compatibility with geth < 1.5 which required
+ // Backwards compatibility with getf < 1.5 which required
// these prefixes.
endpoint = endpoint[4:]
@@ -161,19 +161,19 @@ func remoteConsole(ctx *cli.Context) error {
return rpc.Dial(endpoint)
}
-// ephemeralConsole starts a new geth node, attaches an ephemeral JavaScript
+// ephemeralConsole starts a new getf node, attaches an ephemeral JavaScript
// console to it, executes each of the files specified as arguments and tears
// everything down.
diff --git a/cmd/geth/consolecmd_test.go b/cmd/getf/consolecmd_test.go
similarity index 79%
rename from cmd/geth/consolecmd_test.go
rename to cmd/getf/consolecmd_test.go
index a80bb0c9da..fa4f8b6ae5 100644
--- a/cmd/geth/consolecmd_test.go
+++ b/cmd/getf/consolecmd_test.go
@@ -40,22 +40,22 @@ const (
func TestConsoleWelcome(t *testing.T) {
coinbase := "0x8605cdbbdb6d264aa742e77020dcbc58fcdce182"
- // Start a geth console, make sure it's cleaned up and terminate the console
- geth := runGeth(t,
+ // Start a getf console, make sure it's cleaned up and terminate the console
+ getf := runGeth(t,
"--port", "0", "--maxpeers", "0", "--nodiscover", "--nat", "none",
"--etherbase", coinbase, "--shh",
"console")
// Gather all the infos the welcome message needs to contain
- geth.SetTemplateFunc("goos", func() string { return runtime.GOOS })
- geth.SetTemplateFunc("goarch", func() string { return runtime.GOARCH })
- geth.SetTemplateFunc("gover", runtime.Version)
- geth.SetTemplateFunc("gethver", func() string { return params.Version })
- geth.SetTemplateFunc("niltime", func() string { return time.Unix(0, 0).Format(time.RFC1123) })
- geth.SetTemplateFunc("apis", func() string { return ipcAPIs })
+ getf.SetTemplateFunc("goos", func() string { return runtime.GOOS })
+ getf.SetTemplateFunc("goarch", func() string { return runtime.GOARCH })
+ getf.SetTemplateFunc("gover", runtime.Version)
+ getf.SetTemplateFunc("gethver", func() string { return params.Version })
+ getf.SetTemplateFunc("niltime", func() string { return time.Unix(0, 0).Format(time.RFC1123) })
+ getf.SetTemplateFunc("apis", func() string { return ipcAPIs })
// Verify the actual welcome message to the required template
- geth.Expect(`
+ getf.Expect(`
Welcome to the Geth JavaScript console!
instance: Geth/v{{gethver}}/{{goos}}-{{goarch}}/{{gover}}
@@ -66,7 +66,7 @@ at block: 0 ({{niltime}})
> {{.InputLine "exit"}}
`)
- geth.ExpectExit()
+ getf.ExpectExit()
}
// Tests that a console can be attached to a running node via various means.
@@ -75,56 +75,56 @@ func TestIPCAttachWelcome(t *testing.T) {
coinbase := "0x8605cdbbdb6d264aa742e77020dcbc58fcdce182"
var ipc string
if runtime.GOOS == "windows" {
- ipc = `\\.\pipe\geth` + strconv.Itoa(trulyRandInt(100000, 999999))
+ ipc = `\\.\pipe\getf` + strconv.Itoa(trulyRandInt(100000, 999999))
} else {
ws := tmpdir(t)
defer os.RemoveAll(ws)
- ipc = filepath.Join(ws, "geth.ipc")
+ ipc = filepath.Join(ws, "getf.ipc")
}
// Note: we need --shh because testAttachWelcome checks for default
// list of ipc modules and shh is included there.
- geth := runGeth(t,
+ getf := runGeth(t,
"--port", "0", "--maxpeers", "0", "--nodiscover", "--nat", "none",
"--etherbase", coinbase, "--shh", "--ipcpath", ipc)
time.Sleep(2 * time.Second) // Simple way to wait for the RPC endpoint to open
- testAttachWelcome(t, geth, "ipc:"+ipc, ipcAPIs)
+ testAttachWelcome(t, getf, "ipc:"+ipc, ipcAPIs)
- geth.Interrupt()
- geth.ExpectExit()
+ getf.Interrupt()
+ getf.ExpectExit()
}
func TestHTTPAttachWelcome(t *testing.T) {
coinbase := "0x8605cdbbdb6d264aa742e77020dcbc58fcdce182"
port := strconv.Itoa(trulyRandInt(1024, 65536)) // Yeah, sometimes this will fail, sorry :P
- geth := runGeth(t,
+ getf := runGeth(t,
"--port", "0", "--maxpeers", "0", "--nodiscover", "--nat", "none",
"--etherbase", coinbase, "--rpc", "--rpcport", port)
time.Sleep(2 * time.Second) // Simple way to wait for the RPC endpoint to open
- testAttachWelcome(t, geth, "http://localhost:"+port, httpAPIs)
+ testAttachWelcome(t, getf, "http://localhost:"+port, httpAPIs)
- geth.Interrupt()
- geth.ExpectExit()
+ getf.Interrupt()
+ getf.ExpectExit()
}
func TestWSAttachWelcome(t *testing.T) {
coinbase := "0x8605cdbbdb6d264aa742e77020dcbc58fcdce182"
port := strconv.Itoa(trulyRandInt(1024, 65536)) // Yeah, sometimes this will fail, sorry :P
- geth := runGeth(t,
+ getf := runGeth(t,
"--port", "0", "--maxpeers", "0", "--nodiscover", "--nat", "none",
"--etherbase", coinbase, "--ws", "--wsport", port)
time.Sleep(2 * time.Second) // Simple way to wait for the RPC endpoint to open
- testAttachWelcome(t, geth, "ws://localhost:"+port, httpAPIs)
+ testAttachWelcome(t, getf, "ws://localhost:"+port, httpAPIs)
- geth.Interrupt()
- geth.ExpectExit()
+ getf.Interrupt()
+ getf.ExpectExit()
}
-func testAttachWelcome(t *testing.T, geth *testgeth, endpoint, apis string) {
- // Attach to a running geth note and terminate immediately
+func testAttachWelcome(t *testing.T, getf *testgeth, endpoint, apis string) {
+ // Attach to a running getf note and terminate immediately
attach := runGeth(t, "attach", endpoint)
defer attach.ExpectExit()
attach.CloseStdin()
@@ -134,10 +134,10 @@ func testAttachWelcome(t *testing.T, geth *testgeth, endpoint, apis string) {
attach.SetTemplateFunc("goarch", func() string { return runtime.GOARCH })
attach.SetTemplateFunc("gover", runtime.Version)
attach.SetTemplateFunc("gethver", func() string { return params.Version })
- attach.SetTemplateFunc("etherbase", func() string { return geth.Etherbase })
+ attach.SetTemplateFunc("etherbase", func() string { return getf.Etherbase })
attach.SetTemplateFunc("niltime", func() string { return time.Unix(0, 0).Format(time.RFC1123) })
attach.SetTemplateFunc("ipc", func() bool { return strings.HasPrefix(endpoint, "ipc") })
- attach.SetTemplateFunc("datadir", func() string { return geth.Datadir })
+ attach.SetTemplateFunc("datadir", func() string { return getf.Datadir })
attach.SetTemplateFunc("apis", func() string { return apis })
// Verify the actual welcome message to the required template
diff --git a/cmd/geth/main.go b/cmd/getf/main.go
similarity index 97%
rename from cmd/geth/main.go
rename to cmd/getf/main.go
index 72fbfc62cf..7f92b66bce 100644
--- a/cmd/geth/main.go
+++ b/cmd/getf/main.go
@@ -14,7 +14,7 @@
// You should have received a copy of the GNU General Public License
// along with go-etherfact. If not, see .
// geth is the official command-line client for Ethereum.
package main
import (
@@ -39,7 +39,7 @@ import (
)
const (
- clientIdentifier = "geth" // Client identifier to advertise over the network
+ clientIdentifier = "getf" // Client identifier to advertise over the network
)
var (
@@ -144,7 +144,7 @@ var (
func init() {
// Initialize the CLI app and start Geth
- app.Action = geth
+ app.Action = getf
app.HideVersion = true // we have a command to print the version
app.Copyright = "Copyright 2013-2017 The go-etherfact Authors"
app.Commands = []cli.Command{
@@ -209,10 +209,10 @@ func main() {
}
}
// geth is the main entry point into the system if no special subcommand is ran.
// It creates a default node based on the command line arguments and runs it in
// blocking mode, waiting for it to be shut down.
-func geth(ctx *cli.Context) error {
+func getf(ctx *cli.Context) error {
node := makeFullNode(ctx)
startNode(ctx, node)
node.Wait()
@@ -14,7 +14,7 @@
// You should have received a copy of the GNU General Public License
// along with go-etherfact. If not, see .
-// geth is the official command-line client for Ethereum.
+// getf is the official command-line client for Ethereum.
package main
import (
@@ -209,10 +209,10 @@ func main() {
}
}
-// geth is the main entry point into the system if no special subcommand is ran.
+// getf is the main entry point into the system if no special subcommand is ran.
// It creates a default node based on the command line arguments and runs it in
// blocking mode, waiting for it to be shut down.
diff --git a/cmd/geth/monitorcmd.go b/cmd/getf/monitorcmd.go
similarity index 98%
rename from cmd/geth/monitorcmd.go
rename to cmd/getf/monitorcmd.go
index ed7b7a1695..c4201be7cd 100644
--- a/cmd/geth/monitorcmd.go
+++ b/cmd/getf/monitorcmd.go
@@ -76,7 +76,7 @@ func monitor(ctx *cli.Context) error {
// Attach to an Ethereum node over IPC or RPC
endpoint := ctx.String(monitorCommandAttachFlag.Name)
if client, err = dialRPC(endpoint); err != nil {
- utils.Fatalf("Unable to attach to geth node: %v", err)
+ utils.Fatalf("Unable to attach to getf node: %v", err)
}
defer client.Close()
@@ -93,7 +93,7 @@ func monitor(ctx *cli.Context) error {
if len(list) > 0 {
utils.Fatalf("No metrics specified.\n\nAvailable:\n - %s", strings.Join(list, "\n - "))
} else {
- utils.Fatalf("No metrics collected by geth (--%s).\n", utils.MetricsEnabledFlag.Name)
+ utils.Fatalf("No metrics collected by getf (--%s).\n", utils.MetricsEnabledFlag.Name)
}
}
sort.Strings(monitored)
@@ -158,7 +158,7 @@ func monitor(ctx *cli.Context) error {
return nil
}
// retrieveMetrics contacts the attached geth node and retrieves the entire set
// of collected system metrics.
func retrieveMetrics(client *rpc.Client) (map[string]interface{}, error) {
var metrics map[string]interface{}
@@ -158,7 +158,7 @@ func monitor(ctx *cli.Context) error {
return nil
}
-// retrieveMetrics contacts the attached geth node and retrieves the entire set
+// retrieveMetrics contacts the attached getf node and retrieves the entire set
// of collected system metrics.
func retrieveMetrics(client *rpc.Client) (map[string]interface{}, error) {
diff --git a/cmd/geth/run_test.go b/cmd/getf/run_test.go
similarity index 87%
rename from cmd/geth/run_test.go
rename to cmd/getf/run_test.go
index 2515cebfb2..fe0f34b080 100644
--- a/cmd/geth/run_test.go
+++ b/cmd/getf/run_test.go
@@ -27,7 +27,7 @@ import (
)
func tmpdir(t *testing.T) string {
- dir, err := ioutil.TempDir("", "geth-test")
+ dir, err := ioutil.TempDir("", "getf-test")
if err != nil {
t.Fatal(err)
}
@@ -43,8 +43,8 @@ type testgeth struct {
}
func init() {
- // Run the app if we've been exec'd as "geth-test" in runGeth.
- reexec.Register("geth-test", func() {
+ // Run the app if we've been exec'd as "getf-test" in runGeth.
+ reexec.Register("getf-test", func() {
if err := app.Run(os.Args); err != nil {
fmt.Fprintln(os.Stderr, err)
os.Exit(1)
@@ -61,7 +61,7 @@ func TestMain(m *testing.M) {
os.Exit(m.Run())
}
// spawns geth with the given command line args. If the args don't set --datadir, the
// child g gets a temporary data directory.
func runGeth(t *testing.T, args ...string) *testgeth {
tt := &testgeth{}
@@ -90,9 +90,9 @@ func runGeth(t *testing.T, args ...string) *testgeth {
}()
}
// Boot "geth". This actually runs the test binary but the TestMain
// function will prevent any tests from running.
- tt.Run("geth-test", args...)
+ tt.Run("getf-test", args...)
return tt
}
@@ -61,7 +61,7 @@ func TestMain(m *testing.M) {
os.Exit(m.Run())
}
-// spawns geth with the given command line args. If the args don't set --datadir, the
+// spawns getf with the given command line args. If the args don't set --datadir, the
// child g gets a temporary data directory.
func runGeth(t *testing.T, args ...string) *testgeth {
@@ -90,9 +90,9 @@ func runGeth(t *testing.T, args ...string) *testgeth {
}()
}
- // Boot "geth". This actually runs the test binary but the TestMain
+ // Boot "getf". This actually runs the test binary but the TestMain
// function will prevent any tests from running.